sequence_from_list_value

Function sequence_from_list_value 

pub fn sequence_from_list_value(cx: &mut Cx, list: Value) -> Result<Value>
Adapt a list Value into a sequence Value.

Bridges the kernel list contract to the sequence contract so list data can be consumed through the sequence organ.