sequence_organ_symbol

Function sequence_organ_symbol 

pub fn sequence_organ_symbol() -> Symbol
Symbol naming the sequence organ as a claim subject.

Identifies this crate’s behavior in the kernel claim store so the organ and its operations project into a browse Card.