pub trait KeyEquivalence<K> {
// Required method
fn equivalent(&self, left: &K, right: &K) -> bool;
}Expand description
Policy used to decide whether two table or set keys are equivalent.
Required Methods
Sourcefn equivalent(&self, left: &K, right: &K) -> bool
fn equivalent(&self, left: &K, right: &K) -> bool
Return whether left and right identify the same logical key.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".